[Scummvm-cvs-logs] SF.net SVN: scummvm:[47511] scummvm/trunk/engines/sci/engine/kgraphics.cpp

waltervn at users.sourceforge.net waltervn at users.sourceforge.net
Sun Jan 24 19:57:23 CET 2010


Revision: 47511
          http://scummvm.svn.sourceforge.net/scummvm/?rev=47511&view=rev
Author:   waltervn
Date:     2010-01-24 18:57:23 +0000 (Sun, 24 Jan 2010)

Log Message:
-----------
SCI: Fix list control scrolling in Jones EGA and VGA.

Modified Paths:
--------------
    scummvm/trunk/engines/sci/engine/kgraphics.cpp

Modified: scummvm/trunk/engines/sci/engine/kgraphics.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/kgraphics.cpp	2010-01-24 18:40:29 UTC (rev 47510)
+++ scummvm/trunk/engines/sci/engine/kgraphics.cpp	2010-01-24 18:57:23 UTC (rev 47511)
@@ -779,8 +779,11 @@
 			// Games from early SCI1 onwards use topString
 			upperOffset = GET_SEL32V(s->_segMan, controlObject, topString);
 		} else {
-			// Earlier games use lsTop
-			upperOffset = GET_SEL32V(s->_segMan, controlObject, lsTop);
+			// Earlier games use lsTop or brTop
+			if (lookup_selector(s->_segMan, controlObject, s->_kernel->_selectorCache.brTop, NULL, NULL) == kSelectorVariable)
+				upperOffset = GET_SEL32V(s->_segMan, controlObject, brTop);
+			else
+				upperOffset = GET_SEL32V(s->_segMan, controlObject, lsTop);
 		}
 
 		// Count string entries in NULL terminated string list


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list